@@ -903,17 +903,12 @@ vector<size_t> const& MutableVertexPartition::get_neigh_comms(size_t v, igraph_n
 vector<size_t> MutableVertexPartition::get_neigh_comms(size_t v, igraph_neimode_t mode, vector<size_t> const& constrained_membership)
 {
   vector<size_t> neigh_comms;
-  vector<bool> comm_added(this->n_communities(), false);
   for (size_t u : this->graph->get_neighbours(v, mode))
   {
     if (constrained_membership[v] == constrained_membership[u])
     {
       size_t comm = this->membership(u);
-      if (!comm_added[comm])
-      {
-        neigh_comms.push_back(comm);
-        comm_added[comm];
-      }
+      neigh_comms.push_back(comm);
     }
   }
   return neigh_comms;
